# eric7.WebBrowser.AutoScroll.AutoScroller

Module implementing the automatic scroller.

### Global Attributes

None

### Classes

AutoScroller | Class implementing the automatic scroller.

### Functions

None

## AutoScroller

Class implementing the automatic scroller.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

AutoScroller | Constructor
__indicatorGlobalRect | Private method to calculate the global indicator parameters.
__showIndicator | Private method to show the auto scroll indicator.
__stopScrolling | Private method to stop scrolling.
eventFilter | Public method to handle event for an object.
isEnabled | Public method to get the enabled state.
mouseMove | Public method to handle mouse move events.
mousePress | Public method to handle mouse button presses.
mouseRelease | Public method to handle mouse button releases.
preferencesChanged | Public method to handle a change of the settings.
wheel | Public method to handle a mouse wheel event.

### Static Methods

None

#### AutoScroller (Constructor)

AutoScroller(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### AutoScroller.__indicatorGlobalRect

__indicatorGlobalRect()

Private method to calculate the global indicator parameters.

Return:
  global indicator parameters

Return Type:
  QRect

#### AutoScroller.__showIndicator

__showIndicator(view, pos)

Private method to show the auto scroll indicator.

view (WebBrowserView)
  reference to the view to show the indicator on
pos (QPoint)
  position to show the indicator at

Return:
  flag indicating, that the indicator is shown

Return Type:
  bool

#### AutoScroller.__stopScrolling

__stopScrolling()

Private method to stop scrolling.

#### AutoScroller.eventFilter

eventFilter(obj, evt)

Public method to handle event for an object.

obj (QObject)
  refernce to the object sending the event
evt (QEvent)
  reference to the event to be handled

Return:
  flag indicating, that the event was handled

Return Type:
  bool

#### AutoScroller.isEnabled

isEnabled()

Public method to get the enabled state.

Return:
  enabled state

Return Type:
  bool

#### AutoScroller.mouseMove

mouseMove(evt)

Public method to handle mouse move events.

evt (QMouseEvent)
  reference to the mouse move event

Return:
  flag indicating, that the event was handled

Return Type:
  bool

#### AutoScroller.mousePress

mousePress(view, evt)

Public method to handle mouse button presses.

view (WebBrowserView)
  reference to the web view the button was pressed on
evt (QMouseEvent)
  reference to the mouse button press event

Return:
  flag indicating, that the event was handled

Return Type:
  bool

#### AutoScroller.mouseRelease

mouseRelease(evt)

Public method to handle mouse button releases.

evt (QMouseEvent)
  reference to the mouse button release event

Return:
  flag indicating, that the event was handled

Return Type:
  bool

#### AutoScroller.preferencesChanged

preferencesChanged()

Public method to handle a change of the settings.

#### AutoScroller.wheel

wheel()

Public method to handle a mouse wheel event.

Return:
  flag indicating, that the event was handled

Return Type:
  bool

Up